# Plover Stenograph

A Plover plugin for using newer Stenograph machines (Stentura Protégé and
Fusion, Élan Mira and Cybra, Diamanté, Wave, Luminex) connected to the computer
over USB or Wi-Fi.

This is a work-in-progress rewrite of the
[plover-stenograph-usb](https://github.com/morinted/plover_stenograph_usb) and
[plover-stenograph-wifi](https://github.com/stanographer/plover_stenograph_wifi)
plugins to reuse code and add more protocol functionality.
